@@ -52,6 +52,7 @@ package com.openexchange.mailfilter.json.ajax.actions;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
+import java.util.Collection;
 import java.util.List;
 import java.util.Map.Entry;
 import java.util.Set;
@@ -62,6 +63,7 @@ import org.json.JSONObject;
 import org.json.JSONValue;
 import com.openexchange.exception.OXException;
 import com.openexchange.jsieve.commands.ActionCommand;
+import com.openexchange.jsieve.commands.JSONMatchType;
 import com.openexchange.jsieve.commands.Rule;
 import com.openexchange.jsieve.commands.test.ITestCommand;
 import com.openexchange.jsieve.registry.TestCommandRegistry;
@@ -72,8 +74,10 @@ import com.openexchange.mailfilter.exceptions.MailFilterExceptionCode;
 import com.openexchange.mailfilter.json.ajax.Parameter;
 import com.openexchange.mailfilter.json.ajax.actions.AbstractRequest.Parameters;
 import com.openexchange.mailfilter.json.ajax.json.RuleParser;
+import com.openexchange.mailfilter.json.ajax.servlet.MailFilterExtensionCapabilities;
 import com.openexchange.mailfilter.json.osgi.Services;
 import com.openexchange.tools.servlet.OXJSONExceptionCodes;
+import com.openexchange.tools.session.ServerSessionAdapter;
 
 /**
  * @author <a href="mailto:dennis.sieben@open-xchange.org">Dennis Sieben</a>
@@ -111,13 +115,32 @@ public class MailFilterAction extends AbstractAction<Rule, MailFilterRequest> {
         final MailFilterService mailFilterService = Services.getService(MailFilterService.class);
         final Set<String> capabilities = mailFilterService.getCapabilities(credentials);
         try {
-            final JSONObject tests = getTestAndActionObjects(capabilities);
-            return tests;
+            final JSONObject result = getTestAndActionObjects(capabilities);
+            addSupportedCapabilities(capabilities, result);
+            return result;
         } catch (JSONException e) {
             throw MailFilterExceptionCode.JSON_ERROR.create(e, e.getMessage());
         }
     }
 
+    /**
+     * Adds all supported capabilities to the {@link JSONObject}
+     *
+     * @param capabilities All sieve capabilities
+     * @param jsonObject The json object
+     * @throws JSONException
+     */
+    private void addSupportedCapabilities(Set<String> capabilities, JSONObject jsonObject) throws JSONException {
+        JSONArray caps = new JSONArray();
+        for (MailFilterExtensionCapabilities cap : MailFilterExtensionCapabilities.values()) {
+            if (capabilities.contains(cap.name())) {
+                caps.put(cap.name());
+            }
+        }
+        jsonObject.putOpt("capabilities", caps);
+
+    }
+
     /**
      * {@inheritDoc}
      */
@@ -169,7 +192,7 @@ public class MailFilterAction extends AbstractAction<Rule, MailFilterRequest> {
         final MailFilterService mailFilterService = Services.getService(MailFilterService.class);
         try {
             final Credentials credentials = request.getCredentials();
-            final Rule rule = CONVERTER.parse(getJsonBody(request));
+            final Rule rule = CONVERTER.parse(getJsonBody(request), ServerSessionAdapter.valueOf(request.getSession()));
             return mailFilterService.createFilterRule(credentials, rule);
         } catch (final SieveException e) {
             throw MailFilterExceptionCode.handleSieveException(e);
@@ -247,7 +270,7 @@ public class MailFilterAction extends AbstractAction<Rule, MailFilterRequest> {
             if (rule == null) {
                 throw MailFilterExceptionCode.NO_SUCH_ID.create(uid, credentials.getRightUsername(), credentials.getContextString());
             }
-            CONVERTER.parse(rule, json);
+            CONVERTER.parse(rule, json, ServerSessionAdapter.valueOf(request.getSession()));
             mailFilterService.updateFilterRule(credentials, rule, uid);
         } catch (JSONException e) {
             throw OXJSONExceptionCodes.JSON_BUILD_ERROR.create(e);
@@ -304,26 +327,44 @@ public class MailFilterAction extends AbstractAction<Rule, MailFilterRequest> {
 
     private JSONArray getTestArray(final Set<String> capabilities) throws JSONException {
         TestCommandRegistry testCommandRegistry = Services.getService(TestCommandRegistry.class);
-        final JSONArray testarray = new JSONArray();
-        for (final ITestCommand command : testCommandRegistry.getCommands()) {
-            final JSONObject object = new JSONObject();
-            if (null == command.getRequired() || capabilities.contains(command.getRequired())) {
-                final JSONArray comparison = new JSONArray();
-                object.put("test", command.getCommandName());
-                final List<String[]> jsonMatchTypes = command.getJsonMatchTypes();
+        Collection<ITestCommand> commands = testCommandRegistry.getCommands();
+        JSONArray jTestArray = new JSONArray(commands.size());
+        for (ITestCommand command : commands) {
+            if (isSupported(command, capabilities)) {
+                JSONObject jTestObject = new JSONObject(4);
+                jTestObject.put("test", command.getCommandName());
+                List<JSONMatchType> jsonMatchTypes = command.getJsonMatchTypes();
+                JSONArray jComparisons;
                 if (null != jsonMatchTypes) {
-                    for (final String[] matchtype : jsonMatchTypes) {
-                        final String value = matchtype[0];
-                        if ("".equals(value) || capabilities.contains(value)) {
-                            comparison.put(matchtype[1]);
+                    jComparisons = new JSONArray(jsonMatchTypes.size());
+                    for (JSONMatchType matchtype : jsonMatchTypes) {
+                        String value = matchtype.getRequired();
+                        if (matchtype.getVersionRequirement() <= 1 && ("".equals(value) || capabilities.contains(value))) {
+                            jComparisons.put(matchtype.getJsonName());
                         }
                     }
+                } else {
+                    jComparisons = JSONArray.EMPTY_ARRAY;
                 }
-                object.put("comparison", comparison);
-                testarray.put(object);
+                jTestObject.put("comparison", jComparisons);
+                jTestArray.put(jTestObject);
             }
         }
-        return testarray;
+        return jTestArray;
+    }
+
+    private boolean isSupported(ITestCommand command, Set<String> capabilities) {
+        List<String> requiredCapabilities = command.getRequired();
+        if (null == requiredCapabilities || requiredCapabilities.isEmpty()) {
+            return true;
+        }
+
+        for (String requiredCapability : requiredCapabilities) {
+            if (false == capabilities.contains(requiredCapability)) {
+                return false;
+            }
+        }
+        return true;
     }
 
     private Integer getUniqueId(final JSONObject json) throws OXException {
