@@ -73,4 +73,9 @@ public class RequireCommand extends ControlCommand {
     public HashSet<String> getRequired() {
         return new HashSet<String>(0);
     }
+
+    @Override
+    public void addOptionalRequired(String required) {
+        // do nothing
+    }
 }
