@@ -78,7 +78,9 @@ import com.openexchange.jsieve.visitors.InternalVisitor;
 import com.openexchange.jsieve.visitors.Visitor;
 import com.openexchange.jsieve.visitors.Visitor.OwnType;
 import com.openexchange.mailfilter.Credentials;
+import com.openexchange.mailfilter.MailFilterInterceptorRegistry;
 import com.openexchange.mailfilter.exceptions.MailFilterExceptionCode;
+import com.openexchange.mailfilter.services.Services;
 
 /**
  * This class will be used to filter out special things which are not part of
@@ -240,101 +242,105 @@ public final class SieveTextFilter {
 
     private final String username;
 
+    private final int userId;
+    private final int contextId;
+
     public SieveTextFilter(final Credentials creds) {
         this.username = creds.getRightUsername();
+        this.userId = creds.getUserid();
+        this.contextId = creds.getContextid();
     }
 
-    public SieveTextFilter(final String username) {
-        this.username = username;
-    }
-
-    public static void main(String[] args) {
-        SieveTextFilter stf = new SieveTextFilter("skata");
-        String r = "# Generated by OX Sieve Bundle on Tue Mar 01 15:30:09 CET 2016\n" + "require [ \"date\" , \"vacation\" , \"relational\" , \"imap4flags\", \"fileinto\" ] ;\n\n"
-
-            + "## Flag: vacation|UniqueId:3|Rulename: vacation notice" + "if allof ( currentdate :value \"ge\" \"date\" \"2016-03-02\" , currentdate :value \"le\" \"date\" \"2016-03-09\" )" + " {";
-        stf.readRequire(r);
-    }
-
+    /**
+     * Reads the sieve script from the specified string and parses it to a {@link RuleListAndNextUid} object
+     * which contains a {@link List} of {@link Rule}s and the next unique identifier for a future {@link Rule}
+     * 
+     * @param readFileToString the sieve script to parse
+     * @return a {@link RuleListAndNextUid} object
+     *         which contains a {@link List} of {@link Rule}s and the next unique identifier for a future {@link Rule}
+     * @throws ParseException if a parsing error is occurred
+     * @throws SieveException if a Sieve protocol error is occurred
+     * @throws OXException
+     */
     public RuleListAndNextUid readScriptFromString(final String readFileToString) throws ParseException, SieveException, OXException {
-        boolean errorsinscript = false;
+        boolean errorsInScript = false;
         // The following line strips off the first line of the script
         // final String first = readFileToString.replaceAll("^.*(\r)?\n", "");
-        final String commentedlines = diffremovenotcommentedlines(kickcommentsright(readFileToString), readFileToString);
+        final String commentedLines = diffRemoveNotCommentedLines(kickCommentsRight(readFileToString), readFileToString);
 
         final Node uncommented = new SieveParser(new StringReader(readFileToString)).start();
         // final List<OwnType> jjtAccept = (List<OwnType>)
         // uncommented.jjtAccept(new Visitor(), null);
         // log.debug(jjtAccept);
-        final Node commented = new SieveParser(new StringReader(commentedlines)).start();
+        final Node commented = new SieveParser(new StringReader(commentedLines)).start();
         // log.debug("\n-------------------------");
         // final List<OwnType> jjtAccept2 = (List<OwnType>)
         // commented.jjtAccept(new Visitor(), null);
         // log.debug(jjtAccept2);
-        final ArrayList<RuleComment> rulenames = getRulenames(readFileToString);
-        final ArrayList<Rule> rules = (ArrayList<Rule>) uncommented.jjtAccept(new InternalVisitor(), Boolean.FALSE);
-        final ArrayList<Rule> rules2 = (ArrayList<Rule>) commented.jjtAccept(new InternalVisitor(), Boolean.TRUE);
+        final ArrayList<RuleComment> ruleNames = getRuleNames(readFileToString);
+        final ArrayList<Rule> uncommentedRules = (ArrayList<Rule>) uncommented.jjtAccept(new InternalVisitor(), Boolean.FALSE);
+        final ArrayList<Rule> commentedRules = (ArrayList<Rule>) commented.jjtAccept(new InternalVisitor(), Boolean.TRUE);
         // Attention: After merging the manipulation of finalrules also
         // manipulates rules and rules2
-        final ArrayList<Rule> finalrules = mergerules(rules, rules2);
-        if (addRulenameToFittingCommandAndSetErrors(rulenames, finalrules, readFileToString, commentedlines)) {
-            errorsinscript = true;
+        final ArrayList<Rule> finalRules = mergeRules(uncommentedRules, commentedRules);
+
+        if (addRulenameToFittingCommandAndSetErrors(ruleNames, finalRules, readFileToString, commentedLines)) {
+            errorsInScript = true;
         }
-        final NextUidAndError nextuidanderror = setPosAndMissingErrortextsAndIds(finalrules, readFileToString, commentedlines);
-        if (nextuidanderror.isError()) {
-            errorsinscript = true;
+        final NextUidAndError nextUidAndError = setPosAndMissingErrortextsAndIds(finalRules, readFileToString, commentedLines);
+        if (nextUidAndError.isError()) {
+            errorsInScript = true;
         }
-        return new RuleListAndNextUid(finalrules, nextuidanderror.getNextuid(), errorsinscript);
+
+        MailFilterInterceptorRegistry interceptorRegistry = Services.getService(MailFilterInterceptorRegistry.class);
+        interceptorRegistry.executeBefore(userId, contextId, finalRules);
+
+        return new RuleListAndNextUid(finalRules, nextUidAndError.getNextuid(), errorsInScript);
     }
 
     /**
      * This method is used to get back the resulting sieve script
      *
-     * @param clientrulesandrequire
-     * @return
-     * @throws SieveException
-     * @deprecated Use {@link #writeback(ClientRulesAndRequire, Set)}
-     */
-    @Deprecated
-    public String writeback(final ClientRulesAndRequire clientrulesandrequire) throws SieveException {
-        return writeback(clientrulesandrequire, Collections.<String> emptySet());
-    }
-
-    /**
-     * This method is used to get back the resulting sieve script
-     *
-     * @param clientrulesandrequire
+     * @param clientRulesAndRequire
      * @param capabilities The SIEVE capabilities
      * @return
      * @throws SieveException
+     * @throws OXException
      */
-    public String writeback(final ClientRulesAndRequire clientrulesandrequire, final Set<String> capabilities) throws SieveException {
-        final ArrayList<Rule> finalruleswithrightrequires = addRightRequires(clientrulesandrequire, capabilities);
-        addLines(finalruleswithrightrequires);
-        final ArrayList<Rule> noncommented = new ArrayList<Rule>();
+    public String writeback(final ClientRulesAndRequire clientRulesAndRequire, final Set<String> capabilities) throws SieveException, OXException {
+        MailFilterInterceptorRegistry interceptorRegistry = Services.getService(MailFilterInterceptorRegistry.class);
+        interceptorRegistry.executeAfter(userId, contextId, clientRulesAndRequire.getRules());
+
+        final ArrayList<Rule> finalRulesWithRightRequires = addRightRequires(clientRulesAndRequire, capabilities);
+        addLines(finalRulesWithRightRequires);
+        final ArrayList<Rule> nonCommented = new ArrayList<Rule>();
         final ArrayList<Rule> commented = new ArrayList<Rule>();
-        splitRules(finalruleswithrightrequires, noncommented, commented);
+        splitRules(finalRulesWithRightRequires, nonCommented, commented);
 
         // Convert the rules to jjTree form but only if they are filled
-        Node noncommentednode = null;
-        if (!noncommented.isEmpty()) {
-            noncommentednode = RuleConverter.rulesToNodes(noncommented);
+        Node nonCommentedNode = null;
+        if (!nonCommented.isEmpty()) {
+            nonCommentedNode = RuleConverter.rulesToNodes(nonCommented);
         }
-        final Node commentednode = RuleConverter.rulesToNodes(commented);
+        final Node commentedNode = RuleConverter.rulesToNodes(commented);
 
         // and convert this to a writeable form
-        List<OwnType> noncommentedoutput = new ArrayList<OwnType>();
-        if (null != noncommentednode) {
-            noncommentedoutput = (List<OwnType>) noncommentednode.jjtAccept(new Visitor(), null);
+        List<OwnType> nonCommentedOutput = new ArrayList<OwnType>();
+        if (null != nonCommentedNode) {
+            nonCommentedOutput = (List<OwnType>) nonCommentedNode.jjtAccept(new Visitor(), null);
         }
-        final List<OwnType> commentedoutput = (List<OwnType>) commentednode.jjtAccept(new Visitor(), null);
+        final List<OwnType> commentedOutput = (List<OwnType>) commentedNode.jjtAccept(new Visitor(), null);
 
-        return listToString(interweaving(noncommentedoutput, commentedoutput, clientrulesandrequire.getRules()));
+        if (commentedOutput == null) {
+            throw new SieveException("Commented output is null");
+        }
+
+        return listToString(interweaving(nonCommentedOutput, commentedOutput, clientRulesAndRequire.getRules()));
     }
 
     /**
      * Writes an empty script
-     * 
+     *
      * @return The empty script
      */
     public String writeEmptyScript() {
@@ -400,35 +406,35 @@ public final class SieveTextFilter {
     /**
      * This method goes through all Rules and adds a fitting line number
      *
-     * @param finalrules
+     * @param finalRules
      */
-    private void addLines(final ArrayList<Rule> finalrules) {
+    private void addLines(final ArrayList<Rule> finalRules) {
         // We add one to the first line offset here, so that the first real rule isn't written directly below
         // the require rule
-        int linenumber = FIRST_LINE_OFFSET + 1;
-        for (int i = 0; i < finalrules.size(); i++) {
-            final Rule rule = finalrules.get(i);
+        int lineNumber = FIRST_LINE_OFFSET + 1;
+        for (int i = 0; i < finalRules.size(); i++) {
+            final Rule rule = finalRules.get(i);
             final RuleComment ruleComment = rule.getRuleComment();
             if (null != ruleComment) {
-                LOG.debug("Added line number {} to comment {}", linenumber, ruleComment);
-                ruleComment.setLine(linenumber++);
+                LOG.debug("Added line number {} to comment {}", lineNumber, ruleComment);
+                ruleComment.setLine(lineNumber++);
             }
-            LOG.debug("Added line number {} to rule {}", linenumber, rule);
-            rule.setLinenumber(linenumber);
+            LOG.debug("Added line number {} to rule {}", lineNumber, rule);
+            rule.setLinenumber(lineNumber);
             // Here we add one because a space between two rules looks better
             final ArrayList<Command> commands = rule.getCommands();
             if (null != commands && !commands.isEmpty()) {
-                linenumber += countcommandlines(commands) + 1;
+                lineNumber += countCommandLines(commands) + 1;
             } else {
                 final String text = rule.getText();
                 if (null != text) {
-                    linenumber += countlines(text) + 1;
+                    lineNumber += countLines(text) + 1;
                 }
             }
         }
     }
 
-    private int countlines(final String text) {
+    private int countLines(final String text) {
         int start = 0;
         int number = 0;
         while (true) {
@@ -442,14 +448,14 @@ public final class SieveTextFilter {
         return number;
     }
 
-    private void addPlainTextToRule(final String wholetext, final String commentedtext, final RuleComment ruleComment, final Rule rightrule) {
-        final int linenumber = rightrule.getLinenumber();
-        final int endlinenumber = rightrule.getEndlinenumber();
+    private void addPlainTextToRule(final String wholeText, final String commentedText, final RuleComment ruleComment, final Rule rightRule) {
+        final int lineNumber = rightRule.getLinenumber();
+        final int endLineNumber = rightRule.getEndlinenumber();
         // Known comments aren't written to the plain text part, otherwise they will be doubled when writing back
-        if (rightrule.isCommented()) {
-            rightrule.setText(getRightPart(commentedtext, linenumber, endlinenumber));
+        if (rightRule.isCommented()) {
+            rightRule.setText(getRightPart(commentedText, lineNumber, endLineNumber));
         } else {
-            rightrule.setText(getRightPart(wholetext, linenumber, endlinenumber));
+            rightRule.setText(getRightPart(wholeText, lineNumber, endLineNumber));
         }
     }
 
@@ -458,43 +464,43 @@ public final class SieveTextFilter {
      * and adds the proper require commands according to the actions used in the
      * command within
      *
-     * @param clientrulesandrequire
+     * @param clientRulesAndRequire
      * @param capabilities The SIEVE capabilities
      * @return
      */
-    private ArrayList<Rule> addRightRequires(final ClientRulesAndRequire clientrulesandrequire, final Set<String> capabilities) {
-        final ArrayList<Rule> newruleslist = new ArrayList<Rule>();
-        final Set<String> requireds = new HashSet<String>();
-        for (final Rule rule : clientrulesandrequire.getRules()) {
+    private ArrayList<Rule> addRightRequires(final ClientRulesAndRequire clientRulesAndRequire, final Set<String> capabilities) {
+        final ArrayList<Rule> newRulesList = new ArrayList<Rule>();
+        final Set<String> requires = new HashSet<String>();
+        for (final Rule rule : clientRulesAndRequire.getRules()) {
             if (null == rule.getRequireCommand()) {
-                newruleslist.add(rule);
+                newRulesList.add(rule);
                 final ArrayList<Command> commands = rule.getCommands();
                 if (!rule.isCommented() && null != commands) {
                     for (final Command command : commands) {
                         final Set<String> required = command.getRequired();
                         required.retainAll(capabilities);
-                        requireds.addAll(required);
+                        requires.addAll(required);
                     }
                 }
             }
         }
-        requireds.addAll(clientrulesandrequire.getRequire());
-        if (!requireds.isEmpty()) {
+        requires.addAll(clientRulesAndRequire.getRequire());
+        if (!requires.isEmpty()) {
             final ArrayList<ArrayList<String>> arrayList = new ArrayList<ArrayList<String>>();
-            arrayList.add(new ArrayList<String>(requiredList(requireds)));
-            final ArrayList<Command> commandlist = new ArrayList<Command>();
-            commandlist.add(new RequireCommand(arrayList));
-            newruleslist.add(0, new Rule(commandlist, FIRST_LINE_OFFSET + 1));
+            arrayList.add(new ArrayList<String>(requiredList(requires)));
+            final ArrayList<Command> commandList = new ArrayList<Command>();
+            commandList.add(new RequireCommand(arrayList));
+            newRulesList.add(0, new Rule(commandList, FIRST_LINE_OFFSET + 1));
         }
-        return newruleslist;
+        return newRulesList;
     }
 
-    private static Set<String> requiredList(final Set<String> requireds) {
-        if (requireds.contains("imapflags") && requireds.contains("imap4flags")) {
+    private static Set<String> requiredList(final Set<String> requires) {
+        if (requires.contains("imapflags") && requires.contains("imap4flags")) {
             // Prefer "imap4flags" if both supported
-            requireds.remove("imapflags");
+            requires.remove("imapflags");
         }
-        return requireds;
+        return requires;
     }
 
     /**
@@ -503,39 +509,39 @@ public final class SieveTextFilter {
      *
      * @param ruleComments All the comments which are found and must be applied to a rule
      * @param rules The rules
-     * @param wholetext The whole text of the script
-     * @param commentedtext The commented text of the script
+     * @param wholeText The whole text of the script
+     * @param commentedText The commented text of the script
      * @return true if an errortext and plaintext has been added anywhere false if not
      */
-    private boolean addRulenameToFittingCommandAndSetErrors(final ArrayList<RuleComment> ruleComments, final ArrayList<Rule> rules, final String wholetext, final String commentedtext) {
-        boolean erroradded = false;
+    private boolean addRulenameToFittingCommandAndSetErrors(final ArrayList<RuleComment> ruleComments, final ArrayList<Rule> rules, final String wholeText, final String commentedText) {
+        boolean errorAdded = false;
         for (final RuleComment ruleComment : ruleComments) {
-            int mindiff = Integer.MAX_VALUE;
-            Rule rightrule = null;
+            int minDiff = Integer.MAX_VALUE;
+            Rule rightRule = null;
             for (final Rule rule : rules) {
                 final int abs = getPosDif(rule.getLinenumber() - ruleComment.getLine());
-                if (abs < mindiff) {
-                    mindiff = abs;
-                    rightrule = rule;
+                if (abs < minDiff) {
+                    minDiff = abs;
+                    rightRule = rule;
                 }
             }
-            if (null != rightrule) {
-                final String errortext = ruleComment.getErrortext();
-                if (null != errortext) {
-                    final String errormsg = rightrule.getErrormsg();
-                    rightrule.setErrormsg(null != errormsg ? errormsg + CRLF + errortext : errortext);
-                    if (handleRuleError(wholetext, commentedtext, ruleComment, rightrule)) {
-                        erroradded = true;
+            if (null != rightRule) {
+                final String errorText = ruleComment.getErrortext();
+                if (null != errorText) {
+                    final String errorMsg = rightRule.getErrormsg();
+                    rightRule.setErrormsg(null != errorMsg ? errorMsg + CRLF + errorText : errorText);
+                    if (handleRuleError(wholeText, commentedText, ruleComment, rightRule)) {
+                        errorAdded = true;
                     }
                 } else {
-                    rightrule.setRuleComments(ruleComment);
-                    if (handleRuleError(wholetext, commentedtext, ruleComment, rightrule)) {
-                        erroradded = true;
+                    rightRule.setRuleComments(ruleComment);
+                    if (handleRuleError(wholeText, commentedText, ruleComment, rightRule)) {
+                        errorAdded = true;
                     }
                 }
             }
         }
-        return erroradded;
+        return errorAdded;
     }
 
     /**
@@ -545,7 +551,7 @@ public final class SieveTextFilter {
      * @param commands
      * @return
      */
-    private int countcommandlines(final ArrayList<Command> commands) {
+    private int countCommandLines(final ArrayList<Command> commands) {
         int i = 0;
         for (final Command command : commands) {
             if (command instanceof IfStructureCommand) {
@@ -568,18 +574,18 @@ public final class SieveTextFilter {
      * @param first
      * @return
      */
-    private String diffremovenotcommentedlines(final String test, final String first) {
-        final ArrayList<String> removedcomments = stringToList(test);
+    private String diffRemoveNotCommentedLines(final String test, final String first) {
+        final ArrayList<String> removedComments = stringToList(test);
         final List<String> orig = stringToList(first);
         for (int i = 0; i < orig.size(); i++) {
-            final String removedcommentsline = removedcomments.get(i);
+            final String removedCommentsLine = removedComments.get(i);
             final String origline = orig.get(i);
-            if (removedcommentsline.equals(origline)) {
-                removedcomments.remove(i);
-                removedcomments.add(i, "");
+            if (removedCommentsLine.equals(origline)) {
+                removedComments.remove(i);
+                removedComments.add(i, "");
             }
         }
-        return listToString(removedcomments);
+        return listToString(removedComments);
     }
 
     private void fillup(final List<String> retval, final int i) {
@@ -588,17 +594,17 @@ public final class SieveTextFilter {
         }
     }
 
-    private int getActionCommandSize(final List<ActionCommand> actioncommands) {
+    private int getActionCommandSize(final List<ActionCommand> actionCommands) {
         int size = 0;
-        if (null != actioncommands) {
-            for (final ActionCommand actionCommand : actioncommands) {
+        if (null != actionCommands) {
+            for (final ActionCommand actionCommand : actionCommands) {
                 if (Commands.VACATION.equals(actionCommand.getCommand()) || Commands.ENOTIFY.equals(actionCommand.getCommand()) || Commands.PGP_ENCRYPT.equals(actionCommand.getCommand())) {
                     // The text arguments for vacation end method for enotify are the last in the list
                     final ArrayList<Object> arguments = actionCommand.getArguments();
                     final int size2 = arguments.size();
                     if (0 < size2) {
                         final ArrayList<String> object = (ArrayList<String>) arguments.get(size2 - 1);
-                        size += countlines(object.get(0)) + 1;
+                        size += countLines(object.get(0)) + 1;
                     }
                 } else {
                     size++;
@@ -612,25 +618,25 @@ public final class SieveTextFilter {
         return (i > 0) ? i : Integer.MAX_VALUE;
     }
 
-    private String getRightPart(final String commentedtext, final int linenumber, final int endlinenumber) {
+    private String getRightPart(final String commentedText, final int lineNumber, final int endLineNumber) {
         int start = 0;
         int end = 0;
         int number = 1;
-        while (number < linenumber) {
-            final int indexOf = commentedtext.indexOf(CRLF, start);
+        while (number < lineNumber) {
+            final int indexOf = commentedText.indexOf(CRLF, start);
             start = indexOf + CRLF.length();
             number++;
         }
         end = start;
-        while (number <= endlinenumber) {
-            final int indexOf = commentedtext.indexOf(CRLF, end);
+        while (number <= endLineNumber) {
+            final int indexOf = commentedText.indexOf(CRLF, end);
             end = indexOf + CRLF.length();
             number++;
         }
-        return commentedtext.substring(start, end);
+        return commentedText.substring(start, end);
     }
 
-    private ArrayList<RuleComment> getRulenames(final String readFileToString) throws OXException {
+    private ArrayList<RuleComment> getRuleNames(final String readFileToString) {
         final ArrayList<RuleComment> ruleComments = new ArrayList<RuleComment>();
         final ArrayList<String> stringToList = stringToList(readFileToString);
         for (int i = 0; i < stringToList.size(); i++) {
@@ -639,33 +645,33 @@ public final class SieveTextFilter {
             if (matcher.matches()) {
                 final String flags = matcher.group(1);
                 if (flags.length() > 0) {
-                    String errortext = null;
-                    final List<String> flaglist = Arrays.asList(flags.split(","));
-                    for (final String flag : flaglist) {
+                    String errorText = null;
+                    final List<String> flagList = Arrays.asList(flags.split(","));
+                    for (final String flag : flagList) {
                         final String illegal = flag.replaceAll(LEGAL_FLAG_CHARS, "");
                         if (illegal.length() > 0) {
                             final String error = "Illegal chars inside flags: \"" + illegal + "\"";
-                            if (null != errortext) {
-                                errortext += CRLF + error;
+                            if (null != errorText) {
+                                errorText += CRLF + error;
                             } else {
-                                errortext = error;
+                                errorText = error;
                             }
                         }
                     }
-                    if (null != errortext) {
-                        ruleComments.add(new RuleComment(i + 1, errortext));
+                    if (null != errorText) {
+                        ruleComments.add(new RuleComment(i + 1, errorText));
                     } else {
                         try {
-                            final int uniqueid = Integer.parseInt(matcher.group(2));
-                            ruleComments.add(new RuleComment(flaglist, uniqueid, matcher.group(3), i + 1));
+                            final int uniqueId = Integer.parseInt(matcher.group(2));
+                            ruleComments.add(new RuleComment(flagList, uniqueId, matcher.group(3), i + 1));
                         } catch (final NumberFormatException e) {
                             ruleComments.add(new RuleComment(i + 1, "Unique id is no integer"));
                         }
                     }
                 } else {
                     try {
-                        final int uniqueid = Integer.parseInt(matcher.group(2));
-                        ruleComments.add(new RuleComment(uniqueid, matcher.group(3), i + 1));
+                        final int uniqueId = Integer.parseInt(matcher.group(2));
+                        ruleComments.add(new RuleComment(uniqueId, matcher.group(3), i + 1));
                     } catch (final NumberFormatException e) {
                         ruleComments.add(new RuleComment(i + 1, "Unique id is no integer"));
                     }
@@ -676,18 +682,23 @@ public final class SieveTextFilter {
     }
 
     /**
-     * @param wholetext
-     * @param commentedtext
-     * @param rulename
-     * @param rightrule
+     * @param wholeText
+     * @param commentedText
+     * @param ruleComment
+     * @param rightRule
      * @return true if an errortext and plaintext has been added false otherwise
      */
-    private boolean handleRuleError(final String wholetext, final String commentedtext, final RuleComment rulename, final Rule rightrule) {
-        final String errormsg = rightrule.getErrormsg();
-        if (null != errormsg) {
-            rightrule.setCommands(null);
-            addPlainTextToRule(wholetext, commentedtext, rulename, rightrule);
-            printErrorForUser(MailFilterExceptionCode.SIEVE_ERROR.create(errormsg));
+    private boolean handleRuleError(final String wholeText, final String commentedText, final RuleComment ruleComment, final Rule rightRule) {
+        final String errorMsg = rightRule.getErrormsg();
+        if (null != errorMsg) {
+            rightRule.setCommands(null);
+            try {
+                addPlainTextToRule(wholeText, commentedText, ruleComment, rightRule);
+            } catch (Exception e) {
+                LOG.warn("Unable to add add rule because of: " + e.getMessage());
+                // continue in case an error occurs
+            }
+            printErrorForUser(MailFilterExceptionCode.SIEVE_ERROR.create(errorMsg));
             return true;
         }
         return false;
@@ -706,12 +717,12 @@ public final class SieveTextFilter {
     private List<String> interweaving(final List<OwnType> nonCommentedOutput, final List<OwnType> commentedOutput, final List<Rule> rules) {
         final List<String> retval = new ArrayList<String>();
         retval.add(FIRST_LINE + (new Date()).toString());
-        for (final OwnType owntype : nonCommentedOutput) {
-            final int linenumber = owntype.getLinenumber();
-            final String string = owntype.getOutput().toString();
+        for (final OwnType ownType : nonCommentedOutput) {
+            final int lineNumber = ownType.getLinenumber();
+            final String string = ownType.getOutput().toString();
             final int size = retval.size();
-            if (linenumber > size + 1) {
-                fillup(retval, linenumber - (size + 1));
+            if (lineNumber > size + 1) {
+                fillup(retval, lineNumber - (size + 1));
             }
             retval.addAll(stringToList(string));
         }
@@ -789,57 +800,57 @@ public final class SieveTextFilter {
      * @param readFileToString
      * @return
      */
-    private String kickcommentsright(final String readFileToString) {
+    private String kickCommentsRight(final String readFileToString) {
         final StringBuilder sb = new StringBuilder(readFileToString);
-        boolean dontparse = false;
-        boolean nextchar = false;
-        boolean newline = true;
+        boolean dontParse = false;
+        boolean nextChar = false;
+        boolean newLine = true;
         boolean comment = false;
-        boolean commentremoved = false;
+        boolean commentRemoved = false;
         boolean inQuotes = false;
         for (int i = 0; i < sb.length();) {
             final char c = sb.charAt(i);
             if (c == '\n') {
-                newline = true;
-                nextchar = false;
+                newLine = true;
+                nextChar = false;
                 comment = false;
-                commentremoved = false;
+                commentRemoved = false;
                 i++;
-            } else if (dontparse && c == '\\') {
+            } else if (dontParse && c == '\\') {
                 //Ignore next char
                 i += 2;
-            } else if (!commentremoved && !comment && c == '"') {
+            } else if (!commentRemoved && !comment && c == '"') {
                 // The comment flag is important because otherwise
                 // you could struggle about '"' in comments
-                dontparse = !dontparse;
+                dontParse = !dontParse;
                 inQuotes = !inQuotes;
-                nextchar = false;
+                nextChar = false;
                 i++;
-            } else if (!commentremoved && !comment && c == 't') {
+            } else if (!commentRemoved && !comment && c == 't') {
                 if ("text:".equals(sb.substring(i, i + 5))) {
-                    dontparse = true;
+                    dontParse = true;
                 }
-                nextchar = false;
+                nextChar = false;
                 i++;
-            } else if (!dontparse && !nextchar && newline && c == '#') {
+            } else if (!dontParse && !nextChar && newLine && c == '#') {
                 // Only delete chars at the beginning of a line
                 if ((i == 0 || sb.charAt(i - 1) == '\n') && ((i + COMMENT_TAG.length()) < sb.length()) && COMMENT_TAG.equals(sb.substring(i, i + COMMENT_TAG.length()))) {
                     sb.delete(i, i + COMMENT_TAG.length());
                 }
-                commentremoved = true;
-                nextchar = true;
-                newline = false;
-            } else if (dontparse && c == '.') {
+                commentRemoved = true;
+                nextChar = true;
+                newLine = false;
+            } else if (dontParse && c == '.') {
                 if (sb.charAt(i - 1) == '\n' && sb.charAt(i + 1) == '\r' && !inQuotes) {
-                    dontparse = false;
+                    dontParse = false;
                 }
-                nextchar = false;
+                nextChar = false;
                 i++;
-            } else if (nextchar && c == '#') {
+            } else if (nextChar && c == '#') {
                 comment = true;
                 i++;
             } else {
-                nextchar = false;
+                nextChar = false;
                 i++;
             }
         }
@@ -875,7 +886,7 @@ public final class SieveTextFilter {
      * @param rules2
      * @return
      */
-    private ArrayList<Rule> mergerules(final ArrayList<Rule> rules, final ArrayList<Rule> rules2) {
+    private ArrayList<Rule> mergeRules(final ArrayList<Rule> rules, final ArrayList<Rule> rules2) {
         final ArrayList<Rule> retval = new ArrayList<Rule>();
         retval.addAll(rules);
         retval.addAll(rules2);
@@ -904,39 +915,39 @@ public final class SieveTextFilter {
     }
 
     /**
-     * @param finalrules
-     * @param wholetext
-     * @param commentedtext
+     * @param finalRules
+     * @param wholeText
+     * @param commentedText
      * @return The next uid
      */
-    private NextUidAndError setPosAndMissingErrortextsAndIds(final ArrayList<Rule> finalrules, final String wholetext, final String commentedtext) {
-        final List<Integer> uniqueids = new ArrayList<Integer>();
+    private NextUidAndError setPosAndMissingErrortextsAndIds(final ArrayList<Rule> finalRules, final String wholeText, final String commentedText) {
+        final List<Integer> uniqueIds = new ArrayList<Integer>();
         int max = -1;
         int i = 0;
-        boolean errortext = false;
-        for (int o = 0; o < finalrules.size(); o++) {
-            final Rule rule = finalrules.get(o);
+        boolean errorText = false;
+        for (int o = 0; o < finalRules.size(); o++) {
+            final Rule rule = finalRules.get(o);
             if (null == rule.getRequireCommand()) {
                 final RuleComment ruleComment = rule.getRuleComment();
-                int uniqueid = -1;
-                if (null != ruleComment && -1 != (uniqueid = ruleComment.getUniqueid())) {
-                    if (uniqueid > max) {
-                        max = uniqueid;
+                int uniqueId = -1;
+                if (null != ruleComment && -1 != (uniqueId = ruleComment.getUniqueid())) {
+                    if (uniqueId > max) {
+                        max = uniqueId;
                     }
                 } else {
-                    uniqueids.add(o);
+                    uniqueIds.add(o);
                 }
                 rule.setPosition(i++);
                 if (null != rule.getErrormsg() && null == rule.getText()) {
-                    if (handleRuleError(wholetext, commentedtext, null, rule)) {
-                        errortext = true;
+                    if (handleRuleError(wholeText, commentedText, null, rule)) {
+                        errorText = true;
                     }
                 }
             }
         }
         // Now we go through all the rules which have to unique id
-        for (final Integer id : uniqueids) {
-            final Rule rule = finalrules.get(id);
+        for (final Integer id : uniqueIds) {
+            final Rule rule = finalRules.get(id);
             final RuleComment ruleComment = rule.getRuleComment();
             if (null != ruleComment) {
                 ruleComment.setUniqueid(++max);
@@ -944,30 +955,30 @@ public final class SieveTextFilter {
                 rule.setRuleComments(new RuleComment(++max));
             }
         }
-        return new NextUidAndError(++max, errortext);
+        return new NextUidAndError(++max, errorText);
     }
 
     /**
      * This method splits the given list of rules into two separate lists one
      * for the commented rules and one for the uncommented
      *
-     * @param totalrules
+     * @param totalRules
      *            A list containing all rules
-     * @param noncommented
+     * @param nonCommented
      *            The list which will contain all non-commented rules
      *            afterwards
      * @param commented
      *            The list which will contain all commented rules afterwards
      */
-    private void splitRules(final ArrayList<Rule> totalrules, final ArrayList<Rule> noncommented, final ArrayList<Rule> commented) {
+    private void splitRules(final ArrayList<Rule> totalRules, final ArrayList<Rule> nonCommented, final ArrayList<Rule> commented) {
         // First clear the two output lists
-        noncommented.clear();
+        nonCommented.clear();
         commented.clear();
-        for (final Rule rule : totalrules) {
+        for (final Rule rule : totalRules) {
             if (rule.isCommented()) {
                 commented.add(rule);
             } else {
-                noncommented.add(rule);
+                nonCommented.add(rule);
             }
         }
     }
