@@ -59,6 +59,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.Callable;
 import java.util.concurrent.ConcurrentHashMap;
@@ -75,6 +76,11 @@ import org.slf4j.LoggerFactory;
 import com.google.common.cache.Cache;
 import com.google.common.cache.CacheBuilder;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.config.ConfigurationServices;
+import com.openexchange.config.DefaultInterests;
+import com.openexchange.config.Interests;
+import com.openexchange.config.Reloadable;
+import com.openexchange.config.lean.LeanConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.jsieve.commands.ActionCommand;
@@ -93,17 +99,19 @@ import com.openexchange.jsieve.export.SieveTextFilter.RuleListAndNextUid;
 import com.openexchange.jsieve.export.exceptions.OXSieveHandlerException;
 import com.openexchange.jsieve.export.exceptions.OXSieveHandlerInvalidCredentialsException;
 import com.openexchange.mailfilter.Credentials;
-import com.openexchange.mailfilter.MailFilterProperties;
 import com.openexchange.mailfilter.MailFilterService;
 import com.openexchange.mailfilter.exceptions.MailFilterExceptionCode;
-import com.openexchange.mailfilter.services.Services;
+import com.openexchange.mailfilter.properties.MailFilterProperty;
+import com.openexchange.mailfilter.properties.PasswordSource;
+import com.openexchange.server.ServiceExceptionCode;
+import com.openexchange.server.ServiceLookup;
 
 /**
  * {@link MailFilterServiceImpl}
  *
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public final class MailFilterServiceImpl implements MailFilterService {
+public final class MailFilterServiceImpl implements MailFilterService, Reloadable {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(MailFilterServiceImpl.class);
 
@@ -160,19 +168,67 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
     // ---------------------------------------------------------------------------------------------------------------- //
 
-    private final String scriptname;
-    final boolean useSIEVEResponseCodes;
     private final Cache<HostAndPort, Capabilities> staticCapabilities;
 
+    private final ServiceLookup services;
+
     /**
-     * Initializes a new {@link MailFilterServiceImpl}.
+     * Initialises a new {@link MailFilterServiceImpl}.
+     *
+     * @param services The {@link ServiceLookup} instance
+     * @throws OXException
      */
-    public MailFilterServiceImpl() {
+    public MailFilterServiceImpl(ServiceLookup services) throws OXException {
         super();
-        ConfigurationService config = Services.getService(ConfigurationService.class);
-        scriptname = config.getProperty(MailFilterProperties.Values.SCRIPT_NAME.property);
-        useSIEVEResponseCodes = Boolean.parseBoolean(config.getProperty(MailFilterProperties.Values.USE_SIEVE_RESPONSE_CODES.property));
+        this.services = services;
         staticCapabilities = CacheBuilder.newBuilder().maximumSize(10).expireAfterWrite(30, TimeUnit.MINUTES).build();
+        checkConfigfile();
+    }
+
+    /**
+     * This method checks for a valid properties' file and throws and exception if none is there or one of the properties is missing
+     *
+     * @throws OXException If the properties' file is invalid
+     */
+    private void checkConfigfile() throws OXException {
+        final ConfigurationService config = getService(ConfigurationService.class);
+        try {
+            Properties file = ConfigurationServices.loadPropertiesFrom(config.getFileByName("mailfilter.properties"));
+            if (file.isEmpty()) {
+                throw MailFilterExceptionCode.NO_PROPERTIES_FILE_FOUND.create();
+            }
+            for (final MailFilterProperty property : MailFilterProperty.values()) {
+                if (!property.isOptional() && null == file.getProperty(property.getFQPropertyName())) {
+                    throw MailFilterExceptionCode.PROPERTY_NOT_FOUND.create(property.getFQPropertyName());
+                }
+            }
+            try {
+                Integer.parseInt(file.getProperty(MailFilterProperty.connectionTimeout.getFQPropertyName()));
+            } catch (final NumberFormatException e) {
+                throw MailFilterExceptionCode.PROPERTY_ERROR.create("Property " + MailFilterProperty.connectionTimeout.getFQPropertyName() + " is not an integer value", e);
+            }
+        } catch (IOException e) {
+            throw MailFilterExceptionCode.IO_ERROR.create(e.getMessage(), e);
+        }
+
+        // Check password source
+        final String passwordSrc = config.getProperty(MailFilterProperty.passwordSource.getFQPropertyName());
+        if (passwordSrc == null) {
+            throw MailFilterExceptionCode.NO_VALID_PASSWORDSOURCE.create();
+        }
+        PasswordSource passwordSource = PasswordSource.passwordSourceFor(passwordSrc);
+        switch (passwordSource) {
+            case GLOBAL:
+                final String masterpassword = config.getProperty(MailFilterProperty.masterPassword.getFQPropertyName());
+                if (masterpassword.length() == 0) {
+                    throw MailFilterExceptionCode.NO_MASTERPASSWORD_SET.create();
+                }
+                break;
+            case SESSION:
+                break;
+            default:
+                throw MailFilterExceptionCode.NO_VALID_PASSWORDSOURCE.create();
+        }
     }
 
     /**
@@ -230,21 +286,24 @@ public final class MailFilterServiceImpl implements MailFilterService {
                             throw MailFilterExceptionCode.DUPLICATE_VACATION_RULE.create();
                         }
                     }
+                } else {
+                    // Check for redirect rule
+                    checkRedirects(rule, credentials);
                 }
 
-                changeIncomingVacationRule(rule);
+                changeIncomingVacationRule(credentials.getUserid(), credentials.getContextid(), rule);
 
                 int nextuid = insertIntoPosition(rule, rules, clientrulesandrequire);
                 String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
                 writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 LOGGER.debug("The following sieve script will be written:\n{}", writeback);
-                writeScript(sieveHandler, activeScript, writeback);
+                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
 
                 return nextuid;
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (ParseException e) {
@@ -277,7 +336,11 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
                 ClientRulesAndRequire clientRulesAndReq = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), null, rules.isError());
                 RuleAndPosition rightRule = getRightRuleForUniqueId(clientRulesAndReq.getRules(), uid);
-                changeIncomingVacationRule(rightRule.rule);
+
+                // Check redirect limit
+                checkRedirects(rule, credentials);
+
+                changeIncomingVacationRule(credentials.getUserid(), credentials.getContextid(), rightRule.rule);
                 if (rightRule.position == rule.getPosition()) {
                     clientRulesAndReq.getRules().set(rightRule.position, rule);
                 } else {
@@ -288,13 +351,13 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 writeback = sieveTextFilter.rewriteRequire(writeback, script);
                 LOGGER.debug("The following sieve script will be written:\n{}", writeback);
 
-                writeScript(sieveHandler, activeScript, writeback);
+                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
             } catch (ParseException e) {
                 throw MailFilterExceptionCode.SIEVE_ERROR.create(e, e.getMessage());
             } catch (SieveException e) {
                 throw MailFilterExceptionCode.handleSieveException(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
@@ -336,11 +399,11 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 }
                 String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
                 writeback = sieveTextFilter.rewriteRequire(writeback, script);
-                writeScript(sieveHandler, activeScript, writeback);
+                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (ParseException e) {
@@ -363,11 +426,11 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 String activeScript = sieveHandler.getActiveScript();
                 SieveTextFilter sieveTextFilter = new SieveTextFilter(credentials);
                 String writeback = sieveTextFilter.writeEmptyScript();
-                writeScript(sieveHandler, activeScript, writeback);
+                writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
@@ -389,7 +452,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (NumberFormatException nfe) {
                 throw MailFilterExceptionCode.NAN.create(nfe, MailFilterExceptionCode.getNANString(nfe));
             } catch (RuntimeException re) {
@@ -420,7 +483,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
                 ClientRulesAndRequire clientrulesandrequire = sieveTextFilter.splitClientRulesAndRequire(rules.getRulelist(), flag, rules.isError());
                 List<Rule> clientRules = clientrulesandrequire.getRules();
-                changeOutgoingVacationRule(clientRules);
+                changeOutgoingVacationRule(credentials.getUserid(), credentials.getContextid(), clientRules);
                 if (!flag.equals(CATEGORY_FLAG)) {
                     removeRules(clientRules, CATEGORY_FLAG);
                 }
@@ -438,7 +501,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
@@ -490,7 +553,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
@@ -531,7 +594,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
 
                     String writeback = sieveTextFilter.writeback(clientrulesandrequire, new HashSet<String>(sieveHandler.getCapabilities().getSieve()));
                     writeback = sieveTextFilter.rewriteRequire(writeback, script);
-                    writeScript(sieveHandler, activeScript, writeback);
+                    writeScript(sieveHandler, activeScript, writeback, getScriptName(credentials.getUserid(), credentials.getContextid()));
                 } else {
                     throw MailFilterExceptionCode.NO_ACTIVE_SCRIPT.create();
                 }
@@ -542,7 +605,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } finally {
@@ -590,7 +653,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } catch (IOException e) {
                 throw MailFilterExceptionCode.IO_CONNECTION_ERROR.create(e, sieveHandler.getSieveHost(), Integer.valueOf(sieveHandler.getSievePort()));
             } catch (ParseException e) {
@@ -613,7 +676,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
                 Capabilities capabilities = sieveHandler.getCapabilities();
                 return new HashSet<String>(capabilities.getSieve());
             } catch (OXSieveHandlerException e) {
-                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
             } finally {
                 closeSieveHandler(sieveHandler);
             }
@@ -637,7 +700,7 @@ public final class MailFilterServiceImpl implements MailFilterService {
                             handlerConnect(sieveHandler, credentials.getSubject());
                             return sieveHandler.getCapabilities();
                         } catch (OXSieveHandlerException e) {
-                            throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes);
+                            throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
                         } finally {
                             closeSieveHandler(sieveHandler);
                         }
@@ -654,8 +717,60 @@ public final class MailFilterServiceImpl implements MailFilterService {
         }
     }
 
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.config.Reloadable#reloadConfiguration(com.openexchange.config.ConfigurationService)
+     */
+    @Override
+    public void reloadConfiguration(ConfigurationService configService) {
+        try {
+            checkConfigfile();
+        } catch (OXException e) {
+            LOGGER.error("Error while reloading 'mailfilter.properties': {}", e.getMessage(), e);
+        }
+    }
+
+    /*
+     * (non-Javadoc)
+     *
+     * @see com.openexchange.config.Reloadable#getInterests()
+     */
+    @Override
+    public Interests getInterests() {
+        String[] configFileNames = new String[MailFilterProperty.values().length];
+        int index = 0;
+        for (MailFilterProperty mailFilterProperty : MailFilterProperty.values()) {
+            configFileNames[index++] = mailFilterProperty.getFQPropertyName();
+        }
+        return DefaultInterests.builder().configFileNames("mailfilter.properties").configFileNames(configFileNames).build();
+    }
+
     // ----------------------------------------------------------------------------------------------------------------------- //
 
+    /**
+     * Get the script name for the specified user in the specified context
+     *
+     * @param userId The user identifier
+     * @param contextId the context identifier
+     * @return The script name
+     */
+    private String getScriptName(int userId, int contextId) {
+        LeanConfigurationService config = services.getService(LeanConfigurationService.class);
+        return config.getProperty(userId, contextId, MailFilterProperty.scriptName);
+    }
+
+    /**
+     *
+     * @param userId
+     * @param contextId
+     * @return
+     */
+    private boolean useSIEVEResponseCodes(int userId, int contextId) {
+        LeanConfigurationService config = services.getService(LeanConfigurationService.class);
+        return config.getBooleanProperty(userId, contextId, MailFilterProperty.useSIEVEResponseCodes);
+    }
+
     private List<Rule> exclude(Map<String, List<Rule>> flagged, List<FilterType> exclusionFlags) {
         List<Rule> ret = new ArrayList<Rule>();
         for (FilterType flag : exclusionFlags) {
@@ -717,15 +832,43 @@ public final class MailFilterServiceImpl implements MailFilterService {
         return false;
     }
 
+    /**
+     * Checks the amount of redirect rules in the specified {@link Rule} and compares
+     * those with the 'max_redirect' size (if available) from the Sieve server
+     * 
+     * @param rule The {@link Rule}
+     * @param credentials The {@link Credentials}
+     * @throws OXException if the redirect commands in the specified {@link Rule} exceed
+     *             the maximum allowed that is configured on the Sieve server
+     */
+    private void checkRedirects(Rule rule, Credentials credentials) throws OXException {
+        // Check for redirect rule
+        int size = getRedirectRuleSize(rule);
+        if (size <= 0) {
+            return;
+        }
+        Object maxRedirectObject = getExtendedProperties(credentials).get("MAXREDIRECTS");
+        if (maxRedirectObject == null) {
+            return;
+        }
+        if (false == (maxRedirectObject instanceof Integer)) {
+            return;
+        }
+        Integer maxRedirects = (Integer) maxRedirectObject;
+        if (size > maxRedirects) {
+            throw MailFilterExceptionCode.TOO_MANY_REDIRECT.create();
+        }
+    }
+
     /**
      * Change a vacation rule
      *
      * @param rule the rule to be changed
      * @throws SieveException
      */
-    private void changeIncomingVacationRule(Rule rule) throws SieveException {
-        ConfigurationService config = Services.getService(ConfigurationService.class);
-        String vacationdomains = config.getProperty(MailFilterProperties.Values.VACATION_DOMAINS.property);
+    private void changeIncomingVacationRule(int userId, int contextId, Rule rule) throws SieveException {
+        LeanConfigurationService config = services.getService(LeanConfigurationService.class);
+        String vacationdomains = config.getProperty(userId, contextId, MailFilterProperty.vacationDomains);
 
         if (null != vacationdomains && 0 != vacationdomains.length()) {
             IfCommand ifCommand = rule.getIfCommand();
@@ -764,9 +907,9 @@ public final class MailFilterServiceImpl implements MailFilterService {
      * @param clientrules
      * @throws SieveException
      */
-    private void changeOutgoingVacationRule(List<Rule> clientrules) throws SieveException {
-        ConfigurationService config = Services.getService(ConfigurationService.class);
-        String vacationdomains = config.getProperty(MailFilterProperties.Values.VACATION_DOMAINS.property);
+    private void changeOutgoingVacationRule(int userId, int contextId, List<Rule> clientrules) throws SieveException {
+        LeanConfigurationService config = services.getService(LeanConfigurationService.class);
+        String vacationdomains = config.getProperty(userId, contextId, MailFilterProperty.vacationDomains);
 
         if (null != vacationdomains && 0 != vacationdomains.length()) {
             for (Rule rule : clientrules) {
@@ -836,25 +979,44 @@ public final class MailFilterServiceImpl implements MailFilterService {
         return (null != ruleComment) && (null != ruleComment.getFlags()) && ruleComment.getFlags().contains("vacation") && rule.getIfCommand() != null && ActionCommand.Commands.VACATION.equals(rule.getIfCommand().getFirstCommand());
     }
 
+    /**
+     * Determine the amount of redirect action commands in the given rule
+     *
+     * @param rule The rule
+     * @return the amount of redirect commands
+     */
+    private int getRedirectRuleSize(Rule rule) {
+        int result = 0;
+        if (rule.getIfCommand() != null) {
+            for (ActionCommand command : rule.getIfCommand().getActionCommands()) {
+                if (ActionCommand.Commands.REDIRECT.equals(command.getCommand())) {
+                    result++;
+                }
+            }
+        }
+        return result;
+    }
+
     /**
      * Used to perform checks to set the right script name when writing
      *
      * @param sieveHandler the sieveHandler to use
      * @param activeScript the activeScript
      * @param writeback the write-back String
+     * @param scriptName TODO
      * @throws OXSieveHandlerException
      * @throws IOException
      * @throws UnsupportedEncodingException
      */
-    private void writeScript(SieveHandler sieveHandler, String activeScript, String writeback) throws OXSieveHandlerException, IOException, UnsupportedEncodingException {
+    private void writeScript(SieveHandler sieveHandler, String activeScript, String writeback, String scriptName) throws OXSieveHandlerException, IOException, UnsupportedEncodingException {
         StringBuilder commandBuilder = new StringBuilder(64);
 
-        if (null != activeScript && activeScript.equals(this.scriptname)) {
+        if (null != activeScript && activeScript.equals(scriptName)) {
             sieveHandler.setScript(activeScript, writeback.getBytes(com.openexchange.java.Charsets.UTF_8), commandBuilder);
             sieveHandler.setScriptStatus(activeScript, true, commandBuilder);
         } else {
-            sieveHandler.setScript(this.scriptname, writeback.getBytes(com.openexchange.java.Charsets.UTF_8), commandBuilder);
-            sieveHandler.setScriptStatus(this.scriptname, true, commandBuilder);
+            sieveHandler.setScript(scriptName, writeback.getBytes(com.openexchange.java.Charsets.UTF_8), commandBuilder);
+            sieveHandler.setScriptStatus(scriptName, true, commandBuilder);
         }
     }
 
@@ -889,26 +1051,32 @@ public final class MailFilterServiceImpl implements MailFilterService {
     }
 
     /**
-     *
-     * @param sieveHandler
+     * Connects the specified SIEVE handler.
+     * <p>
+     * Furthermore this method contains a thread synchronization if Kerberos is used. If the Kerberos subject is not <code>null</code>, that Kerberos subject object is used to only allow a single IMAP/SIEVE login per Kerberos
+     * subject. The service ticket for the IMAP/SIEVE server is stored in the Kerberos subject once the IMAP/SIEVE login was successful. If multiple threads can execute this in concurrently, multiple service tickets are
+     * requested, which is discouraged for performance reasons.
+     * 
+     * @param sieveHandler The SIEVE handler to connect
+     * @param kerberosSubject The optional Kerberos subject or <code>null</code>
      * @throws OXException
-     * @throws UnsupportedEncodingException
-     * @throws IOException
      * @throws OXSieveHandlerException
-     * @throws OXSieveHandlerInvalidCredentialsException
      * @throws PrivilegedActionException
+     * @see {@link Credentials#getSubject()}
      */
-    protected void handlerConnect(final SieveHandler sieveHandler, Subject subject) throws OXException, OXSieveHandlerException {
+    protected void handlerConnect(final SieveHandler sieveHandler, Subject kerberosSubject) throws OXException, OXSieveHandlerException {
         try {
-            if (subject != null) {
-                Subject.doAs(subject, new PrivilegedExceptionAction<Object>() {
-
-                    @Override
-                    public Object run() throws Exception {
-                        sieveHandler.initializeConnection();
-                        return null;
-                    }
-                });
+            if (kerberosSubject != null) {
+                synchronized (kerberosSubject) {
+                    Subject.doAs(kerberosSubject, new PrivilegedExceptionAction<Object>() {
+    
+                        @Override
+                        public Object run() throws Exception {
+                            sieveHandler.initializeConnection();
+                            return null;
+                        }
+                    });
+                }
             } else {
                 sieveHandler.initializeConnection();
             }
@@ -949,6 +1117,21 @@ public final class MailFilterServiceImpl implements MailFilterService {
         return nextUid;
     }
 
+    /**
+     * Gets the service of specified type
+     *
+     * @param clazz The service's class
+     * @return The requested service
+     * @throws OXException If the service is not available
+     */
+    private <S extends Object> S getService(final Class<? extends S> clazz) throws OXException {
+        final S service = services.getService(clazz);
+        if (service == null) {
+            throw ServiceExceptionCode.SERVICE_UNAVAILABLE.create(clazz.getSimpleName());
+        }
+        return service;
+    }
+
     // ----------------------------------------------------- Helper classes -------------------------------------------------------
 
     private static final class Key {
@@ -1040,4 +1223,20 @@ public final class MailFilterServiceImpl implements MailFilterService {
         }
     }
 
+    @Override
+    public Map<String, Object> getExtendedProperties(Credentials credentials) throws OXException {
+        Object lock = lockFor(credentials);
+        synchronized (lock) {
+            SieveHandler sieveHandler = SieveHandlerFactory.getSieveHandler(credentials);
+            try {
+                handlerConnect(sieveHandler, credentials.getSubject());
+                Capabilities capabilities = sieveHandler.getCapabilities();
+                return capabilities.getExtendedProperties();
+            } catch (OXSieveHandlerException e) {
+                throw MailFilterExceptionCode.handleParsingException(e, credentials, useSIEVEResponseCodes(credentials.getUserid(), credentials.getContextid()));
+            } finally {
+                closeSieveHandler(sieveHandler);
+            }
+        }
+    }
 }
